@@ -54,6 +54,10 @@ def process_dir(src_dir, dest_dir, keep_days, dry_run):
             if file_stats.skip_reason:
                 stats.skipped_files.append(file_stats)
 
+            print(
+                f"{file_stats.path} -> {f'{skipped: {file_stats.skip_reason}}' if file_stats.skip_reason else file_stats.target_path}"
+            )
+
         # cleanup: remove all empty directories except source
         if not dry_run and root != source:
             remove_empty_dirs(root)
@@ -95,12 +99,13 @@ def print_stats(stats):
         f"Finished at: {stats.finished_at}{os.linesep}"
         f"Time elapsed: {(stats.finished_at - stats.started_at).total_seconds()} seconds{os.linesep}"
     )
+    print()
     print(out)
 
 
 def main(arguments=None):
     if not arguments:
-        arguments = docopt(__doc__, version="imagemv 0.0.2")
+        arguments = docopt(__doc__, version="imagemv 0.1.0")
 
     logging.basicConfig(
         level=logging.DEBUG if arguments.get("--verbose") else logging.INFO
